clear 
echo on
/*
=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
|              Linear Program                 |
=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

  The problem we want to solve is
  
  min   f' x

  s.t.  A x < B
        C x = D

=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
*/

pause, home

// Define matrices (matlab syntax)
A = [1 2 1; -3 -2 -1; -eye(3)];
B = [15 -10 0 0 -2]';
C = [1 1 0];
D = 4;
f = [1 1 1]';

// Define problem variables
var x(3,1) // x is a matrix with dimensions 3 x 1

pause, home

// Define inequality constraints (lmi > 0)
lmi = B-A*x  // A x < B

// Define equality constraints   (lme = 0)
lme = C*x-D  // C x = D

// Define objective              (min obj)
obj = f'*x   // min f' x

pause, home
// Take a look at the workspace with whos
whos

pause, home
// Take a look at the workspace with who
who
pause, home

// Solve the problem
solve;

pause, home

// Look at the solution
x

pause, home

// Define matrices A1, B1 and B2 as
A1 = A(1:2,:)
B1 = B(1:2,:)
B2 = -B(3:5,:)

/*
  
  the inequality constraint set of the last problem
  can be written as

    A1 x < B1
       x > B2  

  This formulation is more meaningful and is also
  supported by LmiSolver. So let's build and solve
  this problem.

*/

pause, home

// We just clear all 'lmi' constraints 
//    (lme and obj remain unchanged)
clear lmi 

// and redefine them as
lmi = B1-A1*x  // A1 x < B
lmi = x-B2     //    x > B2

pause, home

// Now we just run 'solve' once more
solve;  x

pause, home

/*
  
  Now suppose we would like to solve this same problem
  for a different vector B2. Once LmiSolver builds an
  algebraic representation of the problem all we
  have to do is change B2 and call solve again!

*/

B2 = [2 -1 4]';
pause, home

solve; x
