clear
echo on
/*
=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
|              Quadratic Program              |
=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

  The problem we want to solve is

    min   x1
                        2
    s.t.     x2 + 1 > x1

                        2
           x1 + 0.5 > x2
                  
  Thanks to Schur complement this problem can be
  converted in the following semidefinite program

    min   x1

    s.t.  | x2 + 1   x1 |
          |             | > 0
          |     x1    1 |

          | x1 + 0.5   x2 |
          |               | > 0
          |       x2    1 |

  which LmiSolver is able to solve.

=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
*/
pause, home

clear // Clear everything (workspace, variables, lmi, lme and obj)

var x1 x2 // Define x1 and x2 as scalar variables

lmi = block(x2+1; x1 1)   // First linear matrix constraint
lmi = block(x1+0.5; x2 1) // Second linear matrix constraint
// Notice that 'block' gets as parameters only the lower diagonal
// part of the matrix constraint.

obj = x1  // Define objective
pause, home

// Solve problem and look at the solution
solve;
x1, x2
